## Pyxo package :

an easy way to create **XO game** with python.

#### get staretd:

* you need to install the package from the pypi by `pip install pyxo`.
* you are ready to play you just need create a game with the building Engin and the run easy .

```python
from pyxo import Engin

game:Engin = Engin()

game.run()

```
or by running
```shell
$ pyxo
# or
$ python -m pyxo
```
```shell
           _____ _        _____            _____          
          |_   _(_) ___  |_   _|_ _  ___  |_   _|__   ___ 
            | | | |/ __|   | |/ _` |/ __|   | |/ _ \ / _ \
            | | | | (__    | | (_| | (__    | | (_) |  __/
            |_| |_|\___|   |_|\__,_|\___|   |_|\___/ \___|

            by ouhammmourachid                      v1.2.1
          
          
                welcome to the game [X,O]

      that is the roles you should chose one the nomber between (1...9)
                        
                        _|___|___|___|_         
                         | 1 | 2 | 3 |         
                        _|___|___|___|_         
                         | 4 | 5 | 6 |         
                        _|___|___|___|_         
                         | 7 | 8 | 9 |         
                        _|___|___|___|_
                         |   |   |   |

      should we start who will begin first you or your friend !

 press ENTER to begin ..

```
have fun playing with your friend.
